@@ -1,10 +1,12 @@
 from .dataset import (
+    add_entries,
     create_data_structure,
     sanitize_data_structure,
     validate_data_structure,
 )
 
 __all__ = [
+    "add_entries",
     "create_data_structure",
     "sanitize_data_structure",
     "validate_data_structure",
