@@ -26,21 +26,31 @@ class Variable:
     """
     type: Literal["text", "json", "file"]
     payload: Union[str, dict[str, Any], list[Attachment]]
-    
+
     def to_json(self) -> dict[str, Any]:
-        """Convert the Variable to a dict; for type 'file', payload contains Attachment instances and may not be JSON-serializable."""
+        """Convert the Variable to a JSON-like dictionary."""
+
+        if (
+            isinstance(self.payload, list)
+            and all(
+                isinstance(item, (FileAttachment, FileDataAttachment, UrlAttachment))
+                for item in self.payload
+            )
+        ):
+            return {"type": self.type, "payload": [item.to_dict() for item in self.payload]}
+
         return {"type": self.type, "payload": self.payload}
-    
+
     @classmethod
     def from_json(cls, data: dict[str, Any]) -> "Variable":
         """Create a Variable from a JSON-like dictionary.
-        
+
         Args:
             data: Dictionary containing the variable data with 'type' and 'payload' keys
-            
+
         Returns:
             Variable: The created variable instance
-            
+
         Raises:
             ValueError/TypeError: If the data format is invalid or required fields are missing.
             Note: For type 'file', payload must be a list of typed Attachment objects
@@ -64,17 +74,24 @@ class Variable:
             raise ValueError(f"invalid type: {var_type}")
 
         validators = {
-            "text": lambda p: isinstance(p, str),
+            # Accept either plain string or {"text": "..."} form
+            "text": lambda p: isinstance(p, str)
+            or (isinstance(p, dict) and isinstance(p.get("text"), str)),
             "json": lambda p: isinstance(p, dict),
-            "file": lambda p: isinstance(p, list) and all(
-                isinstance(item, (FileAttachment, FileDataAttachment, UrlAttachment)) for item in p
+            # Accept either List[Attachment] or {"files": [...]}
+            "file": lambda p: (
+                isinstance(p, list)
+                and all(isinstance(item, (FileAttachment, FileDataAttachment, UrlAttachment)) for item in p)
+            ) or (
+                isinstance(p, dict)
+                and isinstance(p.get("files"), list)
             ),
         }
         if not validators[var_type](payload):
             messages = {
-                "text": "payload for 'text' must be str",
+                "text": "payload for 'text' must be str or dict with key 'text'",
                 "json": "payload for 'json' must be dict",
-                "file": "payload for 'file' must be list[Attachment] with Attachment instances",
+                "file": "payload for 'file' must be List[Attachment] or dict with key 'files'",
             }
             raise TypeError(messages[var_type])
 
@@ -88,9 +105,9 @@ class VariableFileAttachment:
     id: str
     url: str
     hosted: bool
-    prefix: Optional[str] = None
     props: dict[str, Any]
-    
+    prefix: Optional[str] = None
+
     def to_dict(self) -> dict[str, Any]:
         """Convert to dictionary for JSON serialization."""
         return {k: v for k, v in {
@@ -120,19 +137,19 @@ class DatasetEntry:
     def from_dict(cls, data_dict: dict[str, Any]) -> "DatasetEntry":
         """
         Convert a single dictionary to a DatasetEntry object.
-        
+
         Args:
             data_dict: Dictionary representing a dataset entry
-            
+
         Returns:
             DatasetEntry: DatasetEntry object
-            
+
         Raises:
-            TypeError: If data_dict is not a dict   
+            TypeError: If data_dict is not a dict
         """
         if not isinstance(data_dict, dict):
             raise TypeError("data_dict must be a dict")
-        
+
         variables = {}
         for column_name, value in data_dict.items():
             if isinstance(value, str):
@@ -170,14 +187,14 @@ class DatasetEntryWithRowNo:
     def from_dataset_entry(cls, dataset_entry: DatasetEntry, row_no: int) -> list["DatasetEntryWithRowNo"]:
         """
         Convert a DatasetEntry to a list of DatasetEntryWithRowNo objects.
-        
+
         Args:
             dataset_entry: The DatasetEntry to convert
             row_no: The row number to assign
-            
+
         Returns:
             list[DatasetEntryWithRowNo]: One object per column
-            
+
         Raises:
             TypeError: If dataset_entry is not a DatasetEntry
         """
@@ -191,13 +208,13 @@ class DatasetEntryWithRowNo:
                 type=variable.type,
                 payload=variable.payload,
             ))
-        
+
         return result
 
     def to_dict(self) -> dict[str, Any]:
         """
         Convert the DatasetEntryWithRowNo to a dictionary.
-        
+
         Returns:
             dict[str, Any]: Dictionary with rowNo, columnName, type, and value
         """
